# SampleId1


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from haplohub.models.sample_id1 import SampleId1

# TODO update the JSON string below
json = "{}"
# create an instance of SampleId1 from a JSON string
sample_id1_instance = SampleId1.from_json(json)
# print the JSON string representation of the object
print SampleId1.to_json()

# convert the object into a dict
sample_id1_dict = sample_id1_instance.to_dict()
# create an instance of SampleId1 from a dict
sample_id1_from_dict = SampleId1.from_dict(sample_id1_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


